/*
  user_config_override.h - user configuration overrides my_user_config.h for Sonoff-Tasmota

  Copyright (C) 2019  Theo Arends

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _USER_CONFIG_OVERRIDE_H_
#define _USER_CONFIG_OVERRIDE_H_

// force the compiler to show a warning to confirm that this file is inlcuded
#warning **** user_config_override.h: Using Settings from this File ****

/*****************************************************************************************************\
 * USAGE:
 *   To modify the stock configuration without changing the my_user_config.h file:
 *   (1) copy this file to "user_config_override.h" (It will be ignored by Git)
 *   (2) define your own settings below
 *   (3) for platformio:
 *         define USE_CONFIG_OVERRIDE as a build flags.
 *         ie1 : export PLATFORMIO_BUILD_FLAGS='-DUSE_CONFIG_OVERRIDE'
 *         ie2 : enable in file platformio.ini "build_flags = -Wl,-Tesp8266.flash.1m0.ld -DUSE_CONFIG_OVERRIDE"
 *       for Arduino IDE:
 *         enable define USE_CONFIG_OVERRIDE in my_user_config.h
 ******************************************************************************************************
 * ATTENTION:
 *   - Changes to SECTION1 PARAMETER defines will only override flash settings if you change define CFG_HOLDER.
 *   - Expect compiler warnings when no ifdef/undef/endif sequence is used.
 *   - You still need to update my_user_config.h for major define USE_MQTT_TLS.
 *   - All parameters can be persistent changed online using commands via MQTT, WebConsole or Serial.
\*****************************************************************************************************/

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++         Aenderungen erst ab hier vornehmen.               +++
// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++ _UNIVERSAL_user_config_override.h                         +++
// +++ NoitaercX +++ 13.01.2019 16:05:00                         +++
// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++ Kommentare von mir werden durch '+++' gekennzeichnet.     +++
// +++ ALLES was hier NICHT geaendert werden soll,               +++
// +++ kann als Kommentar // oder /* */ auskommentiert werden    +++
// +++ und bleibt dann so, wie in der my_user_config.h definiert.+++
// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++                Abschnitt 1 (SECTION 1)                    +++
// +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
//#undef  CFG_HOLDER                           // +++ CFG_HOLDER sollte man nur zum Loeschen der Konfiguration von Abschnitt 1 abaendern, danach wieder auf default Wert stellen!
//#define CFG_HOLDER        4617               // [Reset 1] Change this value to load SECTION1 configuration parameters to flash

// +++ eingestelltes Tasmota-Modul - wenn keines gewaehlt wird, dann ist default SONOFF_BASIC voreingestellt
// +++ SONOFF_S2X / SONOFF_POW / SONOFF_RF / SONOFF_TOUCH / SONOFF_T11 / SONOFF_DUAL_R2 / SONOFF_4CH / SONOFF_4CHPRO
// +++ SHELLY1 / SHELLY2 / BLITZWOLF_BWSHP / MAGICHOME / OBI / WEMOS / TECKIN / TUYA_DIMMER usw.
#undef  MODULE																
#define MODULE      SONOFF_BASIC            // [Module] Select default model from sonoff_template.h

// +++ Eigene WLAN-Einstellungen +++++++++++++++++++++++++++
#undef  STA_SSID1                           // [SSId1] Wifi SSID
#define STA_SSID1         ""                // "MeinRouter"
#undef  STA_PASS1                           // [Password1] Wifi password
#define STA_PASS1         ""                // "MeinPasswort"

#undef  STA_SSID2
#define STA_SSID2         ""                // [SSId2] Wifi SSID
#undef  STA_PASS2
#define STA_PASS2         ""                // [Password2] Wifi password

//#undef  WIFI_CONFIG_TOOL                    // [WifiConfig] Default tool if wifi fails to connect
//#define WIFI_CONFIG_TOOL       WIFI_WAIT    // +++ default in my_user_config.h: WIFI_RETRY
#undef  WIFI_CONFIG_NO_SSID                 // +++ geaendert von WIFI_WPSCONFIG = default in my_user_config.h
#define WIFI_CONFIG_NO_SSID    WIFI_MANAGER // Default tool if wifi fails to connect and no SSID is configured

// +++ DHCP oder feste IP +++++++++++++++++++++++++++++++++++++
//#undef  WIFI_IP_ADDRESS
//#define WIFI_IP_ADDRESS        "0.0.0.0"         // [IpAddress1] Set to 0.0.0.0 for using DHCP or IP address
//#undef  WIFI_GATEWAY
//#define WIFI_GATEWAY           "192.168.1.1"     // [IpAddress2] If not using DHCP set Gateway IP address
//#undef  WIFI_SUBNETMASK   
//#define WIFI_SUBNETMASK        "255.255.255.0"   // [IpAddress3] If not using DHCP set Network mask
//#undef  WIFI_DNS
//#define WIFI_DNS               "192.168.1.1"     // [IpAddress4] If not using DHCP set DNS IP address (might be equal to WIFI_GATEWAY)

// +++ Eingetragene OTA Update-URL +++++++++++++++++++++++++
#undef  OTA_URL
#define OTA_URL          "http://thehackbox.org/tasmota/release/020300/sonoff-DE.bin"  // [OtaUrl]

// -- Project -------------------------------------
#undef  PROJECT                             // +++ Default Topic
#define PROJECT          "meinsonoff"       // PROJECT is used as the default topic delimiter

// +++ Eigene MQTT-Einstellungen +++++++++++++++++++++++++++
#undef  MQTT_USE                            // +++ mit '0' ist MQTT beim Start deaktiviert
#define MQTT_USE          0                 // [SetOption3] Select default MQTT use (0 = Off, 1 = On)
#undef  MQTT_HOST
#define MQTT_HOST         "192.168.x.x"     // [MqttHost] +++ MQTT-Host Einstellung
#undef  MQTT_PORT
#define MQTT_PORT         1883              // [MqttPort] +++ MQTT-Port Einstellung
//#undef  MQTT_USER
//#define MQTT_USER         "admin"         // [MqttUser] Optional user
//#undef  MQTT_PASS
//#define MQTT_PASS         "admin"         // [MqttPassword] Optional password

// -- MQTT topics ---------------------------------
// Example "tasmota/bedroom/%topic%/%prefix%/" up to 80 characers
//#undef  MQTT_FULLTOPIC
//#define MQTT_FULLTOPIC         "%prefix%/%topic%/" // [FullTopic] Subscribe and Publish full topic name - Legacy topic
//#undef  MQTT_TOPIC
//#define MQTT_TOPIC             PROJECT             // [Topic] (unique) MQTT device topic, set to 'PROJECT "_%06X"' for unique topic including device MAC address
//#undef  MQTT_GRPTOPIC
//#define MQTT_GRPTOPIC          "sonoffs"           // [GroupTopic] MQTT Group topic
//#undef  MQTT_BUTTON_TOPIC
//#define MQTT_BUTTON_TOPIC      "0"                 // [ButtonTopic] MQTT button topic, "0" = same as MQTT_TOPIC, set to 'PROJECT "_BTN_%06X"' for unique topic including device MAC address
//#undef  MQTT_SWITCH_TOPIC
//#define MQTT_SWITCH_TOPIC      "0"                 // [SwitchTopic] MQTT button topic, "0" = same as MQTT_TOPIC, set to 'PROJECT "_SW_%06X"' for unique topic including device MAC address
//#undef  MQTT_CLIENT_ID
//#define MQTT_CLIENT_ID         "DVES_%06X"         // [MqttClient] Also fall back topic using Chip Id = last 6 characters of MAC address

// -- MQTT - TelePeriode -------------------------------
#undef  TELE_PERIOD                                // +++ 1 min Einstellung (default ist TelePeriod=300 entspricht 5min)
#define TELE_PERIOD            60                  // [TelePeriod] Telemetry (0 = disable, 10 - 3600 seconds)

// -- MQTT - Home Assistant Discovery -------------
//#undef  HOME_ASSISTANT_DISCOVERY_ENABLE
//#define HOME_ASSISTANT_DISCOVERY_ENABLE   1      // [SetOption19] Home Assistant Discovery (0 = Disable, 1 = Enable)

// -- HTTP ----------------------------------------
#undef  FRIENDLY_NAME                       // +++ angezeigter Name des Geraetes
#define FRIENDLY_NAME     "MeinSonoff"      // [FriendlyName] Friendlyname up to 32 characters used by webpages and Alexa

//#undef  EMULATION                                  // +++ Belkin WeMo oder HUE (EMUL_NONE, EMUL_WEMO or EMUL_HUE) wird hier eingestellt
//#define EMULATION              EMUL_WEMO           // [Emulation] Select Belkin WeMo (single relay/light) or Hue Bridge emulation (multi relay/light) (EMUL_NONE, EMUL_WEMO or EMUL_HUE)

// +++ Time - Bis zu drei NTP Server (Zeit-Server)
//#undef  NTP_SERVER1 
//#define NTP_SERVER1            "fritz.box"         // [NtpServer1] Select first NTP server by name or IP address 
#undef  NTP_SERVER2 
#define NTP_SERVER2            "de.pool.ntp.org"   // [NtpServer2] Select second NTP server by name or IP address 
#undef  NTP_SERVER3 
#define NTP_SERVER3            "0.de.pool.ntp.org" // [NtpServer3] Select third NTP server by name or IP address 

// +++ Location -------- Orts-Einstellung ---------
// +++                     'Berlin'
#undef  LATITUDE
#define LATITUDE       52.520006   	      	// [Latitude]  +++ Breitengrad-Angabe fuer die Berechnung von Astro-Zeiten
#undef  LONGITUDE                         	
#define LONGITUDE      13.404954   	      	// [Longitude] +++ Laengengrad-Angabe fuer die Berechnung von Astro-Zeiten

// -- Application ---------------------------------
#undef  APP_TIMEZONE                               // +++ Zeitzone: 99 = Sommer-/Winterzeit
#define APP_TIMEZONE           99                  // [Timezone] +1 hour (Amsterdam) (-13 .. 14 = hours from UTC, 99 = use TIME_DST/TIME_STD)
//#undef  APP_LEDSTATE                               // +++ Funktion der LED am Geraet
//#define APP_LEDSTATE           LED_OFF             // [LedState] Function of led
                                                   //   (LED_OFF, LED_POWER, LED_MQTTSUB, LED_POWER_MQTTSUB, LED_MQTTPUB, LED_POWER_MQTTPUB, LED_MQTT, LED_POWER_MQTT)
//#undef  APP_PULSETIME                              // +++ Einschaltdauer des Relais in msec (bei 0 = deaktiviert)
//#define APP_PULSETIME          0                   // [PulseTime] Time in 0.1 Sec to turn off power for relay 1 (0 = disabled)
//#undef  APP_POWERON_STATE                          // +++ Verhalten des Relais beim Start (wie vorher/aus/ein...)
//#define APP_POWERON_STATE      POWER_ALL_SAVED     // [PowerOnState] Power On Relay state
                                                   //   (POWER_ALL_OFF, POWER_ALL_ON, POWER_ALL_SAVED_TOGGLE, POWER_ALL_SAVED, POWER_ALL_ALWAYS_ON, POWER_ALL_OFF_PULSETIME_ON)
//#undef  APP_SLEEP                                  // +++ Sleep Wert voreinstellen 
//#define APP_SLEEP              0                   // [Sleep] Sleep time to lower energy consumption (0 = Off, 1 - 250 mSec)

//#undef  WS2812_LEDS                                // +++ Anzahl der WS2812 LEDs am Strip (default = 30)
//#define WS2812_LEDS            24                  // [Pixels] Number of WS2812 LEDs to start with (max is 512)

// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++ Befehle in eckigen Klammern koennen direkt in der Tasmota Konsole oder               +++
// +++ per MQTT zur Abfrage bzw. Konfiguration eingegeben werden z.B. [SSId1]               +++
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

// +++ Spracheinstellung +++++++++++++++++++++++++++++++++++
#undef  MY_LANGUAGE
#define MY_LANGUAGE      de-DE                 // German in Germany

// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++                Abschnitt 2 (SECTION 2)                                               +++
// +++ Falls die Funktion in der my_user_config.h aktiviert wurde mit #define               +++
// +++ dann kann sie hier deaktiviert werden                      mit #undef                +++
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

//#undef USE_ENERGY_SENSOR                       // Disable energy sensors
#undef  USE_ARDUINO_OTA                        // Disable support for Arduino OTA
#undef  USE_WPS                                // Disable support for WPS as initial wifi configuration tool
#undef  USE_SMARTCONFIG                        // Disable support for Wifi SmartConfig as initial wifi configuration tool
#undef  USE_MQTT_TLS                           // Disable TLS support won't work as the MQTTHost is not set
//#undef  USE_CUSTOM                             // Disable Custom features

#undef  USE_DOMOTICZ                           // Disable Domoticz (+6k code, +0.3k mem)
#undef  USE_HOME_ASSISTANT                     // Disable Home Assistant Discovery Support (+2k code)
#undef  USE_KNX                                // Disable KNX IP Protocol Support (+9.4k code, +3k7 mem)
  #undef  USE_KNX_WEB_MENU                     // Disable KNX WEB MENU (+8.3k code, +144 mem)

// -- HTTP --------------------------------------- // +++ Achtung: damit kann die Weboberflaeche (Tasmota UI) deaktiviert werden
//#undef  USE_WEBSERVER                          // Disable web server and Wifi Manager (+66k code, +8k mem)
//#undef  USE_EMULATION                          // Disable Belkin WeMo and Hue Bridge emulation for Alexa (+16k code, +2k mem)

// -- mDNS ----------------------------------------
//#undef  USE_DISCOVERY                          // Disable mDNS for both MQTT and web server (+8k code, +0.3k mem)

// -- Time ---------------------------------------- // +++ Achtung: damit kann die Zeitsteuerung (Timer) deaktiviert werden
//#undef  USE_TIMERS                             // Disable support for up to 16 timers (+2k2 code)
// #undef  USE_TIMERS_WEB                        // Disable timer webpage support (+4k5 code)
// #undef  USE_SUNRISE                           // Disable support for Sunrise and sunset tools (+16k)

// -- Rules --------------------------------------- // +++ Achtung: dadurch kann die Verwendung von Rules deaktiviert werden
//#undef  USE_RULES                              // Disable support for rules (+4k4 code)

// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++ Sensoren +++                                                                         +++
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

// -- One wire sensors ---------------------------- // +++ DS18x20 (DS18B20, DS1820, DS18S20) Temperatur-Sensoren
//#undef  USE_DS18x20_LEGACY                       // Optional for more than one DS18x20 sensors with dynamic scan using library OneWire (+1k5 code)
//#undef  USE_DS18x20                              // Optional for more than one DS18x20 sensors with id sort, single scan and read retry (+1k3 code)

// -- I2C sensors --------------------------------- // +++ I2C kann hier mit #undef USE_I2C komplett deaktiviert werden
//#undef  USE_I2C                                  // I2C using library wire (+10k code, 0k2 mem, 124 iram)

// +++ wenn einzelne I2C Sensoren benoetigt werden, dann muss //#undef USE_I2C auskommentiert sein,
// +++ und die benoetigten Sensoren ebenso '//' auskommentiert oder mit #define aktiviert werden.
#ifdef USE_I2C
//  #undef  USE_SHT                                // Disable SHT1X sensor (+1k4 code)
//  #undef  USE_HTU                                // Disable HTU21/SI7013/SI7020/SI7021 sensor (I2C address 0x40) (+1k5 code)
//  #undef  USE_BMP                                // Disable BMP085/BMP180/BMP280/BME280 sensors (I2C addresses 0x76 and 0x77) (+4k4 code)
  #undef  USE_BME680                             // Disable support for BME680 sensor using Bosch BME680 library (+4k code)
  #undef  USE_BH1750                             // Disable BH1750 sensor (I2C address 0x23 or 0x5C) (+0k5 code)
  #undef  USE_VEML6070                           // Disable VEML6070 sensor (I2C addresses 0x38 and 0x39) (+1k5 code)
  #undef  USE_ADS1115                            // Disable ADS1115 16 bit A/D converter (I2C address 0x48, 0x49, 0x4A or 0x4B) based on Adafruit ADS1x15 library (no library needed) (+0k7 code)
  #undef  USE_ADS1115_I2CDEV                     // Disable ADS1115 16 bit A/D converter (I2C address 0x48, 0x49, 0x4A or 0x4B) using library i2cdevlib-Core and i2cdevlib-ADS1115 (+2k code)
  #undef  USE_INA219                             // Disable INA219 (I2C address 0x40, 0x41 0x44 or 0x45) Low voltage and current sensor (+1k code)
  #undef  USE_SHT3X                              // Disable SHT3x (I2C address 0x44 or 0x45) or SHTC3 (I2C address 0x70) sensor (+0k7 code)
  #undef  USE_TSL2561                            // Disable TSL2561 sensor (I2C address 0x29, 0x39 or 0x49) using library Joba_Tsl2561 (+2k3 code)
  #undef  USE_MGS                                // Disable Xadow and Grove Mutichannel Gas sensor using library Multichannel_Gas_Sensor (+10k code)
  #undef  USE_SGP30                              // Disable SGP30 sensor (I2C address 0x58) (+1k1 code)
  #undef  USE_SI1145                             // Disable SI1145/46/47 sensor (I2C address 0x60) (+1k code)
  #undef  USE_LM75AD                             // Disable LM75AD sensor (I2C addresses 0x48 - 0x4F) (+0k5 code)
  #undef  USE_APDS9960                           // Disable APDS9960 Proximity Sensor (I2C address 0x39). Disables SHT and VEML6070 (+4k7 code)
  #undef  USE_MCP230xx                           // Disable MCP23008/MCP23017 - Must define I2C Address in #define USE_MCP230xx_ADDR below - range 0x20 - 0x27 (+4k7 code)
  #undef  USE_PCA9685                            // Disable PCA9685 I2C HW PWM Driver - Must define I2C Address in #define USE_PCA9685_ADDR below - range 0x40 - 0x47 (+1k4 code)
  #undef  USE_MPR121                             // Disable MPR121 controller (I2C addresses 0x5A, 0x5B, 0x5C and 0x5D) in input mode for touch buttons (+1k3 code)
  #undef  USE_CCS811                             // Disable CCS811 sensor (I2C address 0x5A) (+2k2 code)
  #undef  USE_MPU6050                            // Disable MPU6050 sensor (I2C address 0x68 AD0 low or 0x69 AD0 high) (+3K3 of code and 188 Bytes of RAM)
  #undef  USE_DS3231                             // Disable DS3231 external RTC in case no Wifi is avaliable. See docs in the source file (+1k2 code)
  #undef  USE_MGC3130                            // Disable MGC3130 Electric Field Effect Sensor (I2C address 0x42) (+2k7 code, 0k3 mem)
  #undef  USE_PN532_I2C                          // Disable PN532 - Near Field Communication (NFC) controller (+1k6 code)

  #undef  USE_DISPLAY                            // Disable I2C Display Support (+2k code)
#endif  // USE_I2C

// -- SPI sensors --------------------------------- // +++ Serial Peripheral Interface Sensors
#undef  USE_SPI                                  // Hardware SPI using GPIO12(MISO), GPIO13(MOSI) and GPIO14(CLK) in addition to two user selectable GPIOs(CS and DC)

// -- Serial sensors ----------------------------// +++ Serielle Sensoren an RX/TX
#undef  USE_MHZ19                                // Disable support for MH-Z19 CO2 sensor (+2k code)
#undef  USE_SENSEAIR                             // Disable support for SenseAir K30, K70 and S8 CO2 sensor (+2k3 code)
#undef  USE_PMS5003                              // Disable support for PMS5003 and PMS7003 particle concentration sensor (+1k3 code)
#undef  USE_NOVA_SDS                             // Disable support for SDS011 and SDS021 particle concentration sensor (+0k7 code)
#undef  USE_SERIAL_BRIDGE                        // Disable support for software Serial Bridge (+0k8 code)
#undef  USE_SDM120                               // Disable support for Eastron SDM120-Modbus energy meter (+1k7 code)
#undef  USE_SDM630                               // Disable support for Eastron SDM630-Modbus energy meter (+2k code)
#undef  USE_MP3_PLAYER                           // Disable use of the DFPlayer Mini MP3 Player RB-DFR-562 commands: play, volume and stop
//#undef  USE_TUYA_DIMMER                          // Disable support for Tuya Serial Dimmer
#undef  USE_ARMTRONIX_DIMMERS                    // Disable support for Armtronix Dimmers (+1k4 code)
#undef  USE_PS_16_DZ                             // Disable support for PS-16-DZ Dimmer
#undef  USE_AZ7798                               // Disable support for AZ-Instrument 7798 CO2 datalogger (+1k6 code)

// Power monitoring sensors ---------------------// +++ werden bei Geraeten mit Verbrauchsmessung benoetigt
//#undef  USE_PZEM004T                             // Disable support for PZEM004T Energy monitor (+2k code)
//#undef  USE_PZEM_AC                              // Disable support for PZEM014,016 Energy monitor (+1k1 code)
//#undef  USE_PZEM_DC                              // Disable support for PZEM003,017 Energy monitor (+1k1 code)
//#undef  USE_MCP39F501                            // Disable support for MCP39F501 Energy monitor as used in Shelly 2 (+3k1 code)

// -- Low level interface devices -----------------
#undef  USE_MAX31855                             // Disable support for MAX31855 K-Type thermocouple sensor using softSPI
//#undef  USE_IR_REMOTE                            // Send IR remote commands using library IRremoteESP8266 and ArduinoJson (+4k3 code, 0k3 mem, 48 iram)
  #undef  USE_IR_HVAC                            // Support for HVAC (Toshiba, Mitsubishi and LG) system using IR (+3k5 code)
//  #undef  USE_IR_RECEIVE                         // Support for IR receiver (+7k2 code, 264 iram)
//#undef  USE_WS2812                               // WS2812 Led string using library NeoPixelBus (+5k code, +1k mem, 232 iram) - Disable by //
  #undef  USE_WS2812_DMA                         // DMA supports only GPIO03 (= Serial RXD) (+1k mem). When USE_WS2812_DMA is enabled expect Exceptions on Pow
#undef  USE_ARILUX_RF                            // Disable support for Arilux RF remote controller (+0k8 code, 252 iram (non 2.3.0))
//#undef  USE_SR04                                 // Disable support for HC-SR04 ultrasonic devices (+1k code)
#undef  USE_TM1638                               // Disable support for TM1638 switches copying Switch1 .. Switch8 (+1k code)
#undef  USE_HX711                                // Disable support for HX711 load cell (+1k5 code)
  #undef  USE_HX711_GUI                          // Disable optional web GUI to HX711 as scale (+1k8 code)
#undef  USE_RF_FLASH                             // Disable support for flashing the EFM8BB1 chip on the Sonoff RF Bridge. C2CK must be connected to GPIO4, C2D to GPIO5 on the PCB (+3k code)
#undef  USE_TX20_WIND_SENSOR                     // Disable support for La Crosse TX20 anemometer (+2k code)
#undef  USE_RC_SWITCH                            // Disable support for RF transceiver using library RcSwitch (+2k7 code, 460 iram)
#undef  USE_RF_SENSOR                            // Disable support for RF sensor receiver (434MHz or 868MHz) (+0k8 code)
  #undef  USE_THEO_V2                            // Disable support for decoding Theo V2 sensors as documented on https://sidweb.nl using 434MHz RF sensor receiver (+1k4 code)
  #undef  USE_ALECTO_V2                          // Disable support for decoding Alecto V2 sensors like ACH2010, WS3000 and DKW2012 weather stations using 868MHz RF sensor receiver (+1k7 code)
#undef  DEBUG_THEO                               // Disable debug code
#undef  USE_DEBUG_DRIVER                         // Disable debug code

//#undef  USE_ADC_VCC                            // Display Vcc in Power status. Disable for use as Analog input on selected devices

// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++ OPTIONALE FIRMWARE KONFIGURATION                                                     +++
// +++ KEINE oder EINE auswaehlen                                                           +++
// +++ KEINE: entspricht den Einstellungen in my_user_config.h und den oben vorgenommenen.  +++
// +++ EINE:  die dann enthaltenen Features und Sensoren sind in 'RELEASENOTES.md'          +++
// +++        beschrieben, die Einstellungen von Abschnitt 2 werden dadurch ueberschrieben. +++
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

//#define BE_MINIMAL            // +++ 1. Tasmota sonoff-minimal: Minimal Firmware fuer OTA 
//#define USE_CLASSIC           // +++ 2. Tasmota sonoff-classic: mit WPS, SmartConfig und WifiManager
//#define USE_SENSORS           // +++ 3. Tasmota sonoff-sensors: mit den meisten Sensoren
//#define USE_BASIC             // +++ 5. Tasmota sonoff-basic:   OHNE Sensoren
//#define USE_DISPLAYS          // +++ 6. Tasmota sonoff-display: mit aktivierten Display Treibern

// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
// +++ ENDE von Abschnitt 2 (SECTION 2)                                                     +++
// +++ Folgende Zeilen nicht aendern                                                        +++
// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

#endif  // _USER_CONFIG_OVERRIDE_H_